==> haskell-decimal-0.5.2-111-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-decimal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Decimal
version:              0.5.2
visibility:           public
id:                   Decimal-0.5.2-A36O787LZpQDtIbDzWwYT7
key:                  Decimal-0.5.2-A36O787LZpQDtIbDzWwYT7
license:              BSD-3-Clause
copyright:            Paul Johnson, 2013, 2018, 2021.
maintainer:           paul@cogito.org.uk
author:               Paul Johnson
stability:            beta
homepage:             https://github.com/PaulJohnson/Haskell-Decimal
synopsis:             Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.

category:             Math
abi:                  2de46e17e209c3392e6ac62d7d32aca3
exposed:              True
exposed-modules:      Data.Decimal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/Decimal-0.5.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/Decimal-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-decimal
hs-libraries:         HSDecimal-0.5.2-A36O787LZpQDtIbDzWwYT7
depends:              base-4.15.1.0 deepseq-1.4.5.0
haddock-interfaces:   /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html:         /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-decimal-0.5.2-122-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-decimal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Decimal
version:              0.5.2
visibility:           public
id:                   Decimal-0.5.2-JtdXWf9c1fiHjWz0uQrBot
key:                  Decimal-0.5.2-JtdXWf9c1fiHjWz0uQrBot
license:              BSD-3-Clause
copyright:            Paul Johnson, 2013, 2018, 2021.
maintainer:           paul@cogito.org.uk
author:               Paul Johnson
stability:            beta
homepage:             https://github.com/PaulJohnson/Haskell-Decimal
synopsis:             Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.

category:             Math
abi:                  b485914b6ff12841957a9d427e1e13e9
exposed:              True
exposed-modules:      Data.Decimal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/Decimal-0.5.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/Decimal-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-decimal
hs-libraries:         HSDecimal-0.5.2-JtdXWf9c1fiHjWz0uQrBot
depends:              base-4.15.1.0 deepseq-1.4.5.0
haddock-interfaces:   /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html:         /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
